#include "ShaderConstants.fxh"
#include "util.fxh"

struct PS_Input
{
	float3 chunkPos : POSITION;
	float4 position : SV_Position;

#ifndef BYPASS_PIXEL_SHADER
	lpfloat4 color : COLOR;
	snorm float2 uv0 : TEXCOORD_0_FB_MSAA;
	snorm float2 uv1 : TEXCOORD_1_FB_MSAA;
#endif

#ifdef FOG
	float4 fogColor : FOG_COLOR;
#endif
};

struct PS_Output
{
	float4 color : SV_Target;
};

ROOT_SIGNATURE
void main(in PS_Input PSInput, out PS_Output PSOutput)
{
#ifdef BYPASS_PIXEL_SHADER
    PSOutput.color = float4(0.0f, 0.0f, 0.0f, 0.0f);
    return;
#else

#if USE_TEXEL_AA
	float4 diffuse = texture2D_AA(TEXTURE_0, TextureSampler0, PSInput.uv0 );
#else
	float4 diffuse = TEXTURE_0.Sample(TextureSampler0, PSInput.uv0);
#endif

#ifdef SEASONS_FAR
	diffuse.a = 1.0f;
#endif

#if USE_ALPHA_TEST
	#ifdef ALPHA_TO_COVERAGE
		#define ALPHA_THRESHOLD 0.05
	#else
		#define ALPHA_THRESHOLD 0.5
	#endif
	if(diffuse.a < ALPHA_THRESHOLD)
		discard;
#endif

#if defined(BLEND)
	diffuse.a *= PSInput.color.a;
#endif

#if !defined(ALWAYS_LIT)
	diffuse = diffuse * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
#endif

#ifndef SEASONS
	#if !USE_ALPHA_TEST && !defined(BLEND)
		diffuse.a = PSInput.color.a;
	#endif	
	diffuse.rgb *= PSInput.color.rgb;

#else
	float2 uv = PSInput.color.xy;
	diffuse.rgb *= lerp(1.0f, TEXTURE_2.Sample(TextureSampler2, uv).rgb*2.0f, PSInput.color.b);
	diffuse.rgb *= PSInput.color.aaa;
	diffuse.a = 1.0f;
#endif
	float3 cp = frac(PSInput.chunkPos.xyz);

	cp.x=cp.x*3.0-1.1;
	cp.z=cp.z*3.0-1.1;

	//15
	if(PSInput.color.r > 0.999 && PSInput.color.g > 50.0/255.0-0.005 && PSInput.color.g < 50.0/255.0+0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		// (cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup izq

		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch uno
		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch uno
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//14
	if(PSInput.color.r > 244.0/255.0-0.005 && PSInput.color.r < 244.0/255.0+0.005 && PSInput.color.g > 27.0/255.0-0.005 && PSInput.color.g < 27.0/255.0+0.005 && PSInput.color.b < 0.005){
		if(	
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup izq

		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch uno
		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch uno
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//13
	if(PSInput.color.r > 234.0/255.0-0.005 && PSInput.color.r < 234.0/255.0+0.005 && PSInput.color.g > 6.0/255.0-0.005 && PSInput.color.g < 6.0/255.0+0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup izq

		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch uno
		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch uno
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//12
	if(PSInput.color.r > 224.0/255.0-0.005 && PSInput.color.r < 224.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		// (cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup izq

		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch uno
		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch uno
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//11
	if(PSInput.color.r > 214.0/255.0-0.005 && PSInput.color.r < 214.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup izq

		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch uno
		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch uno
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//10
	if(PSInput.color.r > 204.0/255.0-0.005 && PSInput.color.r < 204.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup izq

		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch uno
		(cp.x >= 0.4983 && cp.x <= 0.5650 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch uno
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//9
	if(PSInput.color.r > 193.0/255.0-0.005 && PSInput.color.r < 193.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//8
	if(PSInput.color.r > 183.0/255.0-0.005 && PSInput.color.r < 183.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//7
	if(PSInput.color.r > 173.0/255.0-0.005 && PSInput.color.r < 173.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//6
	if(PSInput.color.r > 163.0/255.0-0.005 && PSInput.color.r < 163.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		// (cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//5
	if(PSInput.color.r > 153.0/255.0-0.005 && PSInput.color.r < 153.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		// (cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//4
	if(PSInput.color.r > 142.0/255.0-0.005 && PSInput.color.r < 142.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//3
	if(PSInput.color.r > 132.0/255.0-0.005 && PSInput.color.r < 132.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//2
	if(PSInput.color.r > 122.0/255.0-0.005 && PSInput.color.r < 122.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		// (cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666)    //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//1
	if(PSInput.color.r > 112.0/255.0-0.005 && PSInput.color.r < 112.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		// (cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup dch

		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		// (cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}
	//0
	if(PSInput.color.r > 76.0/255.0-0.005 && PSInput.color.r < 76.0/255.0+0.005 && PSInput.color.g < 0.005 && PSInput.color.b < 0.005){
		if(	
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3000) || //linea inf
		//(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.4333) || //linea med
		(cp.x >= 0.2316 && cp.x <= 0.4316 && cp.z >= 0.5000 && cp.z <= 0.5666) || //linea sup

		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf dch
		(cp.x >= 0.2316 && cp.x <= 0.2983 && cp.z >= 0.3666 && cp.z <= 0.5666) || //sup dch

		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.2333 && cp.z <= 0.3666) || //inf izq
		(cp.x >= 0.3650 && cp.x <= 0.4316 && cp.z >= 0.3666 && cp.z <= 0.5666)    //sup izq
		){
			diffuse.rgb = float3(1.0f, 1.0f, 1.0f) * TEXTURE_1.Sample(TextureSampler1, PSInput.uv1);
		}
	}

#ifdef FOG
	diffuse.rgb = lerp( diffuse.rgb, PSInput.fogColor.rgb, PSInput.fogColor.a );
#endif

	PSOutput.color = diffuse;

#ifdef VR_MODE
	// On Rift, the transition from 0 brightness to the lowest 8 bit value is abrupt, so clamp to 
	// the lowest 8 bit value.
	PSOutput.color = max(PSOutput.color, 1 / 255.0f);
#endif

#endif // BYPASS_PIXEL_SHADER
}